@@ -14,10 +14,6 @@
 # limitations under the License.
 """Flags and helpers for the Cloud Filestore instances commands."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 from googlecloudsdk.api_lib.filestore import filestore_client
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
@@ -79,25 +75,25 @@ FILE_TIER_TO_TYPE = {
 
 _LDAP_HELP_TEXT = """\
         LDAP configuration for an instance. Specifies the domain name, servers,
-        users_ou, and groups_ou to be created by the filestore instance. users_ou
-        and groups_ou are optional.
+        users-ou, and groups-ou to be created by the filestore instance. users-ou
+        and groups-ou are optional.
 
          domain
             The desired domain name. i.e.:
             'my-domain.com'
 
-          Servers
+          servers
             The desired LDAP servers. i.e.:
             'ldap.example.com', 'ldap2.example.com'
 
-          Usersou
-            The desired usersou.
+          users-ou
+            The desired users Organizational Unit (OU).
 
-          Groups_ou
-            The desired groups_ou.
+          groups-ou
+            The desired groups Organizational Unit (OU).
 
           Use the following format to specify the LDAP configuration:
-            --ldap=^:^domain=my-domain.com:servers=ldap.example.com,ldap2.example.com:users_ou=users:groups_ou=groups
+            --ldap=^:^domain=my-domain.com:servers=ldap.example.com,ldap2.example.com:users-ou=users:groups-ou=groups
   """
 
 _MANAGED_AD_HELP_TEXT = """\
@@ -328,50 +324,78 @@ def AddConnectManagedActiveDirectoryArg(parser):
   )
 
 
-def AddDirectoryServicesArg(parser):
+def AddConnectLdapArg(parser):
   """Adds a --ldap flag to the parser.
 
   Args:
     parser: argparse parser.
   """
-  group = parser.add_group(
-      help='Directory services configuration for an instance.',
-      required=False,
-      mutex=True,
-  )
-
-  managed_ad_arg_spec = {
-      'domain': str,
-      'computer': str,
-  }
-  group.add_argument(
-      '--managed-ad',
-      type=arg_parsers.ArgDict(
-          spec=managed_ad_arg_spec, required_keys=['domain', 'computer']
-      ),
-      required=False,
-      help=_MANAGED_AD_HELP_TEXT,
-  )
 
   ldap_arg_spec = {
       'domain': str,
       'servers': str,
-      'users_ou': str,
-      'groups_ou': str,
+      'users-ou': str,
+      'groups-ou': str,
   }
 
-  group.add_argument(
+  parser.add_argument(
       '--ldap',
-      metavar='^:^domain=DOMAIN:servers=SERVER1,SERVER2:users_ou=USERSOU:groups_ou=GROUPSOU',
+      metavar='^:^domain=DOMAIN:servers=SERVER1,SERVER2:users-ou=USERSOU:groups-ou=GROUPSOU',
       type=arg_parsers.ArgDict(
           spec=ldap_arg_spec,
           required_keys=['domain', 'servers'],
       ),
       required=False,
       help=_LDAP_HELP_TEXT,
+      hidden=True,
   )
 
 
+def AddDisconnectLdapArg(parser):
+  """Adds a --disconnect-ldap flag to the parser.
+
+  Args:
+    parser: argparse parser.
+  """
+
+  disconnect_ldap_help = """\
+        Disconnect the instance from LDAP."""
+
+  parser.add_argument(
+      '--disconnect-ldap',
+      action='store_true',
+      required=False,
+      hidden=True,
+      help=disconnect_ldap_help,
+  )
+
+
+def AddDirectoryServicesArg(parser, api_version):
+  """Adds --managed-ad and --ldap flags to the parser.
+
+  Args:
+    parser: argparse parser.
+    api_version: filestore_client api version.
+  """
+
+  # Managed AD is not supported in alpha.
+  if api_version == filestore_client.ALPHA_API_VERSION:
+    return
+  # Managed AD and LDAP are both supported in beta.
+  elif api_version == filestore_client.BETA_API_VERSION:
+    group = parser.add_group(
+        help='Directory services configuration for an instance.',
+        required=False,
+        mutex=True,
+    )
+
+    AddConnectManagedActiveDirectoryArg(group)
+    AddConnectLdapArg(group)
+  # LDAP is supported in GA.
+  else:
+    AddConnectLdapArg(parser)
+
+
 def AddDisconnectManagedActiveDirectoryArg(parser):
   """Adds a --disconnect-managed-ad flag to the parser.
 
@@ -390,16 +414,24 @@ def AddDisconnectManagedActiveDirectoryArg(parser):
   )
 
 
-def AddManagedActiveDirectoryConnectionArgs(parser):
-  """Adds a --managed-ad flag to the parser.
+def AddDirectoryServicesConnectDisconnectArgs(parser, api_version):
+  """Adds --managed-ad, --disconnect-managed-ad, --ldap, --disconnect-ldap flags to the parser.
 
   Args:
     parser: argparse parser.
+    api_version: filestore_client api version.
   """
 
-  connection_arg_group = parser.add_mutually_exclusive_group()
-  AddConnectManagedActiveDirectoryArg(connection_arg_group)
-  AddDisconnectManagedActiveDirectoryArg(connection_arg_group)
+  connection_arg_group = parser.add_mutually_exclusive_group(
+      hidden=api_version == filestore_client.V1_API_VERSION,
+  )
+  # Managed AD is supported in beta only.
+  if api_version == filestore_client.BETA_API_VERSION:
+    AddConnectManagedActiveDirectoryArg(connection_arg_group)
+    AddDisconnectManagedActiveDirectoryArg(connection_arg_group)
+  # LDAP is supported in both beta and GA.
+  AddConnectLdapArg(connection_arg_group)
+  AddDisconnectLdapArg(connection_arg_group)
 
 
 def AddSourceInstanceArg(parser):
@@ -410,12 +442,12 @@ def AddSourceInstanceArg(parser):
   )
 
 
-def AddNetworkArg(parser,
-                  api_version):
+def AddNetworkArg(parser, api_version):
   """Adds a --network flag to the given parser.
 
   Args:
     parser: argparse parser.
+    api_version: filestore_client api version.
   """
 
   network_arg_spec_v1 = {
@@ -762,9 +794,13 @@ def AddInstanceCreateArgs(parser, api_version):
   AddNetworkArg(parser, api_version)
   messages = filestore_client.GetMessages(version=api_version)
   GetTierArg(messages).choice_arg.AddToParser(parser)
-  if api_version == filestore_client.BETA_API_VERSION:
+
+  if api_version in [
+      filestore_client.BETA_API_VERSION,
+      filestore_client.V1_API_VERSION,
+  ]:
     GetProtocolArg(messages).choice_arg.AddToParser(parser)
-    AddDirectoryServicesArg(parser)
+    AddDirectoryServicesArg(parser, api_version)
   AddFileShareArg(
       parser,
       api_version,
@@ -794,8 +830,6 @@ def AddInstanceUpdateArgs(parser, api_version):
   AddRegionArg(parser)
   AddAsyncFlag(parser)
   labels_util.AddUpdateLabelsFlags(parser)
-  if api_version == filestore_client.BETA_API_VERSION:
-    AddManagedActiveDirectoryConnectionArgs(parser)
   AddFileShareArg(
       parser,
       api_version,
@@ -809,5 +843,6 @@ def AddInstanceUpdateArgs(parser, api_version):
       filestore_client.BETA_API_VERSION,
       filestore_client.V1_API_VERSION,
   ]:
+    AddDirectoryServicesConnectDisconnectArgs(parser, api_version)
     AddPerformanceArg(parser)
     dp_util.AddDeletionProtectionUpdateArgs(parser)
