@@ -388,21 +388,7 @@ def AddFinalBackup(parser):
   )
 
 
-def AddFinalbackupTtlDays(parser):
-  help_text = (
-      'Specifies number of days to retain final backup. The valid range is'
-      ' between 1 and 365. Default value is 30 days.'
-  )
-  parser.add_argument(
-      '--final-backup-ttl-days',
-      type=arg_parsers.BoundedInt(1, 365, unlimited=False),
-      required=False,
-      hidden=True,
-      help=help_text,
-  )
-
-
-def AddFinalbackupRetentionDays(parser):
+def AddFinalbackupRetentionDays(parser, hidden=False):
   help_text = (
       'Specifies number of days to retain final backup. The valid range is'
       ' between 1 and 365. Default value is 30 days.'
@@ -411,6 +397,7 @@ def AddFinalbackupRetentionDays(parser):
       '--final-backup-retention-days',
       type=arg_parsers.BoundedInt(1, 365, unlimited=False),
       required=False,
+      hidden=hidden,
       help=help_text,
   )
 
@@ -1154,6 +1141,21 @@ def AddSimulateMaintenanceEvent(parser):
   )
 
 
+def AddReconcilePsaNetworking(parser):
+  """Adds the `--reconcile-psa-networking` flag to the parser."""
+  parser.add_argument(
+      '--reconcile-psa-networking',
+      action='store_true',
+      required=False,
+      help=(
+          "Reconciles the instance's PSA networking configuration. If the "
+          "instance is already on a PSA network, the DNS zone and records "
+          "associated with the PSA write endpoint are either added if missing "
+          "or updated if incorrect."
+      ),
+  )
+
+
 def AddSqlServerAudit(parser, hidden=False):
   """Adds SQL Server audit related flags to the parser."""
   parser.add_argument(
