@@ -407,7 +407,9 @@ class Update(base.UpdateCommand):
     flags.AddWorkloadVulnScanningEnumFlag(group)
     flags.AddRuntimeVulnerabilityInsightFlag(group)
     flags.AddWorkloadPoliciesFlag(group)
+    flags.AddAutopilotWorkloadPoliciesFlag(group)
     flags.AddRemoveWorkloadPoliciesFlag(group)
+    flags.AddRemoveAutopilotWorkloadPoliciesFlag(group)
     flags.AddEnableMultiNetworkingFlag(group)
     flags.AddContainerdConfigFlag(group)
     flags.AddAutoprovisioningResourceManagerTagsUpdate(group)
@@ -444,10 +446,13 @@ class Update(base.UpdateCommand):
     )
     flags.AddEnableDNSAccessFlag(group_for_control_plane_endpoints)
     flags.AddEnableK8sTokensViaDnsFlag(group_for_control_plane_endpoints)
+    flags.AddEnableK8sCertsViaDnsFlag(group_for_control_plane_endpoints)
     flags.AddServiceAccountVerificationKeysFlag(group)
     flags.AddServiceAccountSigningKeysFlag(group)
     flags.AddPatchUpdateFlag(group)
     flags.AddAutoIpamFlag(group, hidden=True, is_update=True)
+    flags.AddEnableLegacyLustrePortFlag(group, hidden=True)
+    flags.AddEnableDefaultComputeClassFlag(group)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -594,6 +599,9 @@ class Update(base.UpdateCommand):
     opts.enable_auto_ipam = args.enable_auto_ipam
     opts.disable_auto_ipam = args.disable_auto_ipam
     opts.enable_k8s_tokens_via_dns = args.enable_k8s_tokens_via_dns
+    opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
+    opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
+    opts.enable_default_compute_class = args.enable_default_compute_class
     return opts
 
   def Run(self, args):
@@ -945,6 +953,14 @@ to completion."""
         )
       except apitools_exceptions.HttpError as error:
         raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
+    elif getattr(args, 'enable_legacy_lustre_port', None) is not None:
+      try:
+        op_ref = adapter.ModifyLegacyLustrePortEnabled(
+            cluster_ref,
+            args.enable_legacy_lustre_port,
+        )
+      except apitools_exceptions.HttpError as error:
+        raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
     elif (
         getattr(args, 'enable_insecure_binding_system_authenticated', None)
         is not None
@@ -1162,7 +1178,9 @@ class UpdateBeta(Update):
     flags.AddWorkloadVulnScanningEnumFlag(group)
     flags.AddRuntimeVulnerabilityInsightFlag(group)
     flags.AddWorkloadPoliciesFlag(group)
+    flags.AddAutopilotWorkloadPoliciesFlag(group)
     flags.AddRemoveWorkloadPoliciesFlag(group)
+    flags.AddRemoveAutopilotWorkloadPoliciesFlag(group)
     flags.AddEnableFqdnNetworkPolicyFlag(group)
     flags.AddHostMaintenanceIntervalFlag(group)
     flags.AddInTransitEncryptionFlag(group)
@@ -1202,10 +1220,13 @@ class UpdateBeta(Update):
     )
     flags.AddEnableDNSAccessFlag(group_for_control_plane_endpoints)
     flags.AddEnableK8sTokensViaDnsFlag(group_for_control_plane_endpoints)
+    flags.AddEnableK8sCertsViaDnsFlag(group_for_control_plane_endpoints)
     flags.AddServiceAccountVerificationKeysFlag(group)
     flags.AddServiceAccountSigningKeysFlag(group)
     flags.AddPatchUpdateFlag(group)
     flags.AddAutoIpamFlag(group, hidden=True, is_update=True)
+    flags.AddEnableLegacyLustrePortFlag(group, hidden=True)
+    flags.AddEnableDefaultComputeClassFlag(group)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -1403,6 +1424,9 @@ class UpdateBeta(Update):
     opts.enable_auto_ipam = args.enable_auto_ipam
     opts.disable_auto_ipam = args.disable_auto_ipam
     opts.enable_k8s_tokens_via_dns = args.enable_k8s_tokens_via_dns
+    opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
+    opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
+    opts.enable_default_compute_class = args.enable_default_compute_class
     return opts
 
 
@@ -1502,7 +1526,9 @@ class UpdateAlpha(Update):
     flags.AddWorkloadVulnScanningEnumFlag(group)
     flags.AddRuntimeVulnerabilityInsightFlag(group)
     flags.AddWorkloadPoliciesFlag(group)
+    flags.AddAutopilotWorkloadPoliciesFlag(group)
     flags.AddRemoveWorkloadPoliciesFlag(group)
+    flags.AddRemoveAutopilotWorkloadPoliciesFlag(group)
     flags.AddEnableFqdnNetworkPolicyFlag(group)
     flags.AddHostMaintenanceIntervalFlag(group)
     flags.AddInTransitEncryptionFlag(group)
@@ -1542,10 +1568,13 @@ class UpdateAlpha(Update):
     )
     flags.AddEnableDNSAccessFlag(group_for_control_plane_endpoints)
     flags.AddEnableK8sTokensViaDnsFlag(group_for_control_plane_endpoints)
+    flags.AddEnableK8sCertsViaDnsFlag(group_for_control_plane_endpoints)
     flags.AddServiceAccountVerificationKeysFlag(group)
     flags.AddServiceAccountSigningKeysFlag(group)
     flags.AddPatchUpdateFlag(group)
     flags.AddAutoIpamFlag(group, hidden=True, is_update=True)
+    flags.AddEnableLegacyLustrePortFlag(group, hidden=True)
+    flags.AddEnableDefaultComputeClassFlag(group)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -1739,4 +1768,7 @@ class UpdateAlpha(Update):
     opts.enable_auto_ipam = args.enable_auto_ipam
     opts.disable_auto_ipam = args.disable_auto_ipam
     opts.enable_k8s_tokens_via_dns = args.enable_k8s_tokens_via_dns
+    opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
+    opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
+    opts.enable_default_compute_class = args.enable_default_compute_class
     return opts
